package main

import (
	"fmt"
	"github.com/spf13/cobra"
	"os"
	"rinne.dev/doh-resolver/app/cmd"
	"rinne.dev/doh-resolver/pkg/config"
	"rinne.dev/doh-resolver/pkg/console"
)

func main() {
	var rootCmd = &cobra.Command{
		Use:  "doh_resolver",
		Long: `Default will run "run" command, you can use "-h" flag to see all subcommands`,
		PersistentPreRun: func(command *cobra.Command, args []string) {
			config.InitConfig(cmd.Config)
		},
	}

	// 注册命令
	rootCmd.AddCommand(
		cmd.Run,
	)

	// 配置默认命令
	cmd.RegisterDefaultCmd(rootCmd, cmd.Run)

	// 注册全局参数
	cmd.RegisterGlobalFlags(rootCmd)

	// 执行主命令
	if err := rootCmd.Execute(); err != nil {
		console.Exit(fmt.Sprintf("Failed to run app with %v: %s", os.Args, err.Error()))
	}
}
